@@ -3,20 +3,21 @@ use Mojo::Util qw/url_escape/;
 sub Mojo::Webqq::Client::_get_offpic {
     my $self = shift;
     my $file_path = shift;
-    my $friend  = shift;
+    my $sender  = shift;
+    my $cb      = pop;
     
     #my $api = 'http://w.qq.com/d/channel/get_offpic2';
     my $api = 'http://d.web2.qq.com/channel/get_offpic2';
     my @query_string = (
         file_path   =>  url_escape($file_path),
-        f_uin       =>  $friend->id,
+        f_uin       =>  $sender->id,
         clientid    =>  $self->clientid,  
         psessionid  =>  $self->psessionid,
     );
     my $callback = sub{
         my ($data,$ua,$tx) = @_;
         unless(defined $data){
-            $self->warn("好友图片下载失败: " . $tx->error->{message});
+            $self->warn("图片下载失败: " . $tx->error->{message});
             return;
         }
         return unless $tx->res->headers->content_type =~/^image\/(.*)/;
@@ -27,27 +28,27 @@ sub Mojo::Webqq::Client::_get_offpic {
                     :                           undef
         ;
         return unless defined $type; 
-        if(defined $self->friend_pic_dir and not -d $self->friend_pic_dir){
-            $self->error("无效的 friend_pic_dir: " . $self->friend_pic_dir);
+        if(defined $self->pic_dir and not -d $self->pic_dir){
+            $self->error("无效的 pic_dir: " . $self->pic_dir);
             return;
         }
         my @opt = (
-            TEMPLATE    => "webqq_offpic_XXXX",
+            TEMPLATE    => "mojo_webqq_offpic_XXXX",
             SUFFIX      => $type,
             UNLINK      => 0,
         );
-        defined $self->friend_pic_dir?(push @opt,(DIR=>$self->friend_pic_dir)):(push @opt,(TMPDIR=>1));
+        defined $self->pic_dir?(push @opt,(DIR=>$self->pic_dir)):(push @opt,(TMPDIR=>1));
         eval{
             my $tmp = File::Temp->new(@opt);
             binmode $tmp;
             print $tmp $tx->res->body();    
             close $tmp;
-            open(my $fh,"<:raw",$tmp->filename) or die $!;
-            $self->emit(receive_friend_pic => $fh,$tmp->filename,$friend);
-            $self->emit(receive_offpic => $fh,$tmp->filename,$friend);
-            close $fh;
+            $self->emit(receive_pic => $tmp->filename,$sender);
+            $self->emit(receive_friend_pic => $tmp->filename,$sender) if $sender->type eq "friend";
+            $self->emit(receive_sess_pic => $tmp->filename,$sender) if $sender->type ne "friend";
+            $cb->($self,$tmp->filename,$sender) if ref $cb eq "CODE";
         };
-        $self->error("[Mojo::Webqq::Client::_get_offpic] $@\n") if $@;
+        $self->error("[Mojo::Webqq::Client::_get_offpic] $@") if $@;
     };
     $self->http_get($self->gen_url($api,@query_string),{Referer=>'http://w.qq.com/'},$callback);
 };
